package Qt::Svg::QSvgGenerator;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QSvgGenerator
# file     : QtSvg/qsvggenerator.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Gui::QPaintDevice/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Svg::QSvgGenerator

=head1 PUBLIC METHODS

=over

=item   QSvgGenerator()

=item   ~QSvgGenerator()

=item  QString description()

=item  QString fileName()

=item  QIODevice * outputDevice()

=item  int resolution()

=item  void setDescription()

=item  void setFileName()

=item  void setOutputDevice()

=item  void setResolution()

=item  void setSize()

=item  void setTitle()

=item  void setViewBox()

=item  void setViewBox()

=item  QSize size()

=item  QString title()

=item  QRect viewBox()

=item  QRectF viewBoxF()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
